==> ath1121501_1.8.2.tar.gz: ath1121501/man/ath1121501ENZYME.Rd <==
\name{ath1121501ENZYME}
\alias{ath1121501ENZYME}
\title{Map Between Manufacturer IDs and Enzyme Commission (EC) Numbers}
\description{ 
  ath1121501ENZYME is an R environment that provides mappings between
  manufacturer ids and EC numbers. 
}
\details{
  Each manufacturer id maps to a named vector containing the EC number that
  corresponds to the enzyme produced by that gene. The name corresponds
  to the manufacturer id. If this information is unknown, the vector
  will contain an \code{NA}.
  
  Enzyme Commission numbers are assigned by the Nomenclature Committee
  of the International Union of Biochemistry and Molecular Biology
  \url{http://www.chem.qmw.ac.uk/iubmb/enzyme/} to allow enzymes to be
  identified. 
  
  An Enzyme Commission number is of the format EC x.y.z.w, where x, y, z,
  and w are numeric numbers. In ath1121501ENZYME2PROBE, EC is dropped from the
  Enzyme Commission numbers.

  Enzyme Commission numbers have corresponding names that describe the
  functions of enzymes in such a way that EC x is a more general
  description than EC x.y that in turn is a more general description than
  EC x.y.z. The top level EC numbers and names are listed below:

  EC 1 oxidoreductases
  
  EC 2 transferases

  EC 3 hydrolases

  EC 4 lyases
  
  EC 5 isomerases
  
  EC 6 ligases
  
  The EC name for a given EC number can be viewed at
  \url{http://www.chem.qmul.ac.uk/iupac/jcbn/index.html#6} 
  
  Mappings between probe ids and enzyme ids were obtained using files
  provided by:

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Pathways/aracyc_dump_20050412}
Built: N/A

  Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{ftp://ftp.arabidopsis.org/home/tair/Genes/Gene_Anatomy/ATH_Anatomy.20040209.txt}
Built: N/A
  
  Package built Tue May 17 18:45:34 2005
}
\references{
\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}
}
\examples{
        # Convert to a list
        xx <- as.list(ath1121501ENZYME)
        # Remove probe ids that do not map to any enzyme EC number
        xx <- xx[!is.na(xx)]
        if(length(xx) > 0){
        # Gets the enzyme commission numbers for the first five
        #probes
        xx[1:5]
        # Get the first one
        xx[[1]]
}
}
\keyword{datasets}

==> ath1121501_1.10.0.tar.gz: ath1121501/man/ath1121501ENZYME.Rd <==
\name{ath1121501ENZYME}
\alias{ath1121501ENZYME}
\title{Map Between Manufacturer IDs and Enzyme Commission (EC) Numbers}
\description{ 
  ath1121501ENZYME is an R environment that provides mappings between
  manufacturer ids and EC numbers. 
}
\details{
  Each manufacturer id maps to a named vector containing the EC number that
  corresponds to the enzyme produced by that gene. The name corresponds
  to the manufacturer id. If this information is unknown, the vector
  will contain an \code{NA}.
  
  Enzyme Commission numbers are assigned by the Nomenclature Committee
  of the International Union of Biochemistry and Molecular Biology
  \url{http://www.chem.qmw.ac.uk/iubmb/enzyme/} to allow enzymes to be
  identified. 
  
  An Enzyme Commission number is of the format EC x.y.z.w, where x, y, z,
  and w are numeric numbers. In ath1121501ENZYME2PROBE, EC is dropped from the
  Enzyme Commission numbers.

  Enzyme Commission numbers have corresponding names that describe the
  functions of enzymes in such a way that EC x is a more general
  description than EC x.y that in turn is a more general description than
  EC x.y.z. The top level EC numbers and names are listed below:

  EC 1 oxidoreductases
  
  EC 2 transferases

  EC 3 hydrolases

  EC 4 lyases
  
  EC 5 isomerases
  
  EC 6 ligases
  
  The EC name for a given EC number can be viewed at
  \url{http://www.chem.qmul.ac.uk/iupac/jcbn/index.html#6} 
  
  Mappings between probe ids and enzyme ids were obtained using files
  provided by:

  Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Pathways/aracyc_dump_20050412}
Built: N/A

  Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/gene_aliases.20041105}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Genes/TAIR_sequenced_genes}
Tair: \url{http://gopher5/compbio/annotationSourceData/ftp.arabidopsis.org/home/tair/Ontologies/TAIR_Ontology/ATH_anatomy.20050119.txt}
Built: N/A
  
  Package built Tue Oct  4 19:05:27 2005
}
\references{
\url{ftp://ftp.genome.ad.jp/pub/kegg/pathways}
}
\examples{
        # Convert to a list
        xx <- as.list(ath1121501ENZYME)
        # Remove probe ids that do not map to any enzyme EC number
        xx <- xx[!is.na(xx)]
        if(length(xx) > 0){
        # Gets the enzyme commission numbers for the first five
        #probes
        xx[1:5]
        # Get the first one
        xx[[1]]
}
}
\keyword{datasets}
